@@ -180,6 +180,8 @@ class StandardEngineSegment(BaseStandard):
 
         loader = ModelLoader(self._conf)
 
+        nrows_score = 0
+
         for path_to_pickle_dir, sample_pickle_file, prefix in zip(paths_to_pickle_dir, sample_pickle_files, prefixes):
 
             self._conf, self.models_dict, self.processor, self.feature_engineering, sep_timetag = loader.load_model(sample_pickle_file)
@@ -196,12 +198,18 @@ class StandardEngineSegment(BaseStandard):
                 )
 
                 self._conf, self.models_dict, self.processor, self.feature_engineering, sep_timetag = loader.load_model(filename)
+
                 tag = next(iter(self.models_dict))
                 self.loaded_models_dict[tag] = self.models_dict[tag]
 
                 self.predict(seg_id, seg_border)
+
                 # we need to make sure we add the number of predictions from all the segments
-                loader.conf.model.nrows_score += self._conf.model.nrows_score
+                nrows_score += self._conf.model.nrows_score
+
+        # we need to assign the total number of predictions for later validation
+        # we also don't want to double count if we have multiple models
+        self._conf.model.nrows_score = nrows_score / len(paths_to_pickle_dir)
 
     @timeit("make predictions using the trained model(s)")
     def predict(self, seg_id=None, seg_border=None):
